@@ -24,3 +24,8 @@ void About::changeEvent(QEvent *e)
         break;
     }
 }
+
+void About::on_textBrowser_anchorClicked(QUrl )
+{
+    this->close();
+}
